@@ -222,6 +222,7 @@ def debug_tran_print(data):
     # 　　4季报 （年报）：每年1月1日——4月30日。
     #todo: 年报和一季度报最迟披露时间一致，默认返回年报
 def getReportDate(dateTime:int,isUseYear = True):
+    # isUseYear:True 返回年报日期 Fasle 返回一季度日期
     mmdd = dateTime % 10000
     year = dateTime // 10000
     dateRange = [1031, 830, 430, ]  # 公布日期
@@ -234,18 +235,52 @@ def getReportDate(dateTime:int,isUseYear = True):
             return year * 10 ** 4 + reportDate[idx]
     return (year - 1) * 10 ** 4 + reportDate[0]
 
+def getTTmReportDates(reportDate):
+    """返回一年滚动需要查询的报告期
+        上年同季度日期，上年的年报日期，当季报告期
+
+        如果reportDate是年报日期。则直接返回reportDate
+    """
+    quarterDate = reportDate % 10 ** 4
+    if quarterDate == 1231:
+        return [reportDate]
+    lastYear = reportDate // 10 ** 4 - 1
+    quarterDates = list(set([reportDate % 10 ** 4, 1231]))
+    reportDates = [lastYear * 10 ** 4 + q for q in quarterDates]
+    reportDates.append(reportDate)
+    return reportDates
+
 @Decorator.loadData()
-def getSymbolsInfo():
+def getSymbolsInfo(isRealTime = False,**kwargs):
+    """[生成股票代码，名称，和行业]
+
+    Args:
+        isRealTime (bool, optional): [如果为True，会增量添加数据]. Defaults to False.
+
+    Returns:
+        [type]: [description]
+    """
+    fileName = kwargs["fileName"]
     # todo：get_stock_codes 获取全市场股票ID.退市的股票有可能获取不到
-    stock_codes = get_stock_codes(real_time=True, stock_type="stock", with_exchange=True)
+    stock_codes = get_stock_codes(real_time=isRealTime, stock_type="stock", with_exchange=True)
+    cathchedSymbols = []
+    
+    if  os.path.exists(fileName):
+        df = pd.read_excel(fileName, sheet_name="数据源", index_col=0,engine="openpyxl")
+        cathchedSymbols = df["symbol"].tolist()
+
+    symbols = [symbol for symbol,name in stock_codes]
+    catchSymbols = list(set(symbols)-set(cathchedSymbols)) # 需要增加的股票
     url = "http://f10.eastmoney.com/CompanySurvey/CompanySurveyAjax"
     params = {
         "code":"",
     }
     data = []
-    cnt = len(stock_codes)
+    cnt = len(catchSymbols)
     i = 0
     for symbol,name in stock_codes:
+        if symbol not in catchSymbols:
+            continue
         i+=1
         print(f"{symbol}{name}\t{i}/{cnt}")
     # for symbol,name in [("SZ.300104","乐视")]:
@@ -259,10 +294,11 @@ def getSymbolsInfo():
             continue
         listingDate = pd.to_datetime(dataJson["fxxg"]["ssrq"]) if dataJson["fxxg"]["ssrq"].replace("--","") else np.nan
         series = pd.Series({"symbol":symbol,"name":name,"listingDate":listingDate})
-        print(series)
         data.append(series)
-        
-    df = pd.DataFrame(data)
+    if cathchedSymbols:
+        df = df.append(pd.DataFrame(data))
+    else:
+        df = pd.DataFrame(data)
     return df
 if __name__ == '__main__':
 
@@ -276,5 +312,6 @@ if __name__ == '__main__':
     # print(getReportDate(20120831))
     # print(getReportDate(20121130))
     # print(pow(2.5,1/11))
+    # print(getSymbolsInfo(isRealTime=True))
     print(getSymbolsInfo())
 # http://f10.eastmoney.com/CompanySurvey/Index?type=web&code=SZ300104
\ No newline at end of file
